Computes approximate distribution parameters for the binomial, hypergeometric,
Poisson, Exponential and normal distribution for a given mean (and standard deviation).
With the sample and the population size the computation can be influenced.
Usage
distributionParams(mean, sd, n = 30, N = 60)
Value
a list of parameters for each distribution
Arguments
mean
numeric: mean
sd
numeric: standard deviation (only used for the normal distribution)