| gettext | R Documentation |
Returns a translation from loaded PO-file. If the message is not found in the PO-file then original text will be returned.
gettext(msg, utype = "vector")
msg |
character: message(s) to translate |
utype |
character: how to return the translated message as vector or named list |
translated messages
msgs <- c("two.sided", "less", "greater")
gettext(msgs)
# for use in Shiny "choices"
gettext(msgs, "name")
gettext(msgs, "numeric")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.