Learn R Programming

HKRbook (version 0.1.3)

men_asso: Association

Description

Shiny app for the association coefficients between two categorical variables. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.

Usage

men_asso(...)

Value

nothing

Arguments

...

one or more data sets

Examples

Run this code
if (interactive()) men_asso()
if (interactive()) men_asso(HairEyeColor, Titanic)

Run the code above in your browser using DataLab