Learn R Programming

HKRbook (version 0.1.3)

men_ci2: men_ci2

Description

Shiny app for a confidence interval for the difference of two means. The data used is considered as a population from which random samples can be drawn. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.

Usage

men_ci2(...)

Value

nothing

Arguments

...

one or more data sets

Examples

Run this code
if (interactive()) men_ci2()
if (interactive()) men_ci2(CO2)

Run the code above in your browser using DataLab