Learn R Programming

HKRbook (version 0.1.3)

men_corr: Correlation

Description

Shiny app for the correlation coefficients between two numeric variables. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.

Usage

men_corr(...)

Value

nothing

Arguments

...

one or more data sets

Examples

Run this code
if (interactive()) men_corr()
if (interactive()) men_corr(iris)

Run the code above in your browser using DataLab