Learn R Programming

HKRbook (version 0.1.3)

men_hist: men_hist

Description

Shiny app for visualizing a univariate numeric variable as histögram. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory. #'

Usage

men_hist(...)

Value

nothing

Arguments

...

one or more data sets

Examples

Run this code
if (interactive()) men_hist()
if (interactive()) men_hist(iris)

Run the code above in your browser using DataLab