powered by
Visualization of the probability mass and the cumulative distribution function of a hypergeometric distribution.
men_hyp(N = 60, M = 30, n = 20)
nothing
integer: the number of black and white balls in the urn
integer: the number of white balls in the urn
integer: the number of balls drawn from the urn
if (interactive()) men_hyp() if (interactive()) men_hyp(50, 25, 10)
Run the code above in your browser using DataLab