Learn R Programming

HKRbook (version 0.1.3)

men_parn: men_parn

Description

Shiny app for the distribution of sample parameters. The data used is considered as a population from which random samples can be drawn. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.

Usage

men_parn(...)

Value

nothing

Arguments

...

one or more data sets

Examples

Run this code
if (interactive()) men_parn()
if (interactive()) men_parn(iris)

Run the code above in your browser using DataLab