Learn R Programming

HKRbook (version 0.1.3)

men_poi: men_poi Visualization of the probability mass and the cumulative distribution function of a Poisson distribution.

Description

men_poi Visualization of the probability mass and the cumulative distribution function of a Poisson distribution.

Usage

men_poi(lambda = 5)

Value

nothing

Arguments

lambda

numeric: (non-negative) mean

Examples

Run this code
if (interactive()) men_poi()
if (interactive()) men_poi(3)

Run the code above in your browser using DataLab