Learn R Programming

HKRbook (version 0.1.3)

men_tab: Frequency tables

Description

Shiny app for frequency tables for two categorical variables. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.

Usage

men_tab(...)

Value

nothing

Arguments

...

one or more data sets

Examples

Run this code
if (interactive()) men_tab()
if (interactive()) men_tab(HairEyeColor, Titanic)

Run the code above in your browser using DataLab