Learn R Programming

HKRbook (version 0.1.3)

men_terr: men_terr

Description

Shiny app for a test for the true mean. The data used is considered as a population from which random samples can be drawn. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.

Usage

men_terr(...)

Value

nothing

Arguments

...

one or more data sets

Examples

Run this code
if (interactive()) men_terr()
if (interactive()) men_terr(iris)

Run the code above in your browser using DataLab