Learn R Programming

HKRbook (version 0.1.3)

men_time: men_time

Description

Shiny app for classical time series analysis If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.

Usage

men_time(...)

Value

nothing

Arguments

...

one or more time series

Examples

Run this code
if (interactive()) men_time()
if (interactive()) men_time(co2)

Run the code above in your browser using DataLab