Learn R Programming

HKRbook (version 0.1.3)

men_tmu2: men_tmu2

Description

Shiny app for a test on difference of two true means. The data used is considered as a population from which random samples can be drawn. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.

Usage

men_tmu2(...)

Value

nothing

Arguments

...

one or more data sets

Examples

Run this code
if (interactive()) men_tmu2()
if (interactive()) men_tmu2(CO2)

Run the code above in your browser using DataLab