Learn R Programming

HKRbook (version 0.1.3)

men_vis: men_vis

Description

Shiny app for visualizing the univariate numeric variable, e.g. boxplot, stripchart, histogram, and cumulative distribution function. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.

Usage

men_vis(...)

Value

nothing

Arguments

...

one or more data sets

Examples

Run this code
if (interactive()) men_vis()
if (interactive()) men_vis(iris)

Run the code above in your browser using DataLab