Based on range the position of the labels are determined and the axis is plotted.
Usage
mmstat.axis(side, range, at, labels, ...)
Value
adds a axis to a plot
Arguments
side
an integer specifying which side of the plot the axis is
to be drawn on. The axis is placed as follows: 1=below,
2=left, 3=above and 4=right.
range
range: a data range
at
the points at which tick-marks are to be drawn. Non-finite
(infinite, NaN or NA) values are omitted. By default
(when NULL) tickmark locations are computed, see
‘Details’ below.
labels
this can either be a logical value specifying whether
(numerical) annotations are to be made at the tickmarks, or a
character or expression vector of labels to be placed at the
tickpoints. (Other objects are coerced by as.graphicsAnnot.)
If this is not logical, at should also be supplied and of the
same length. If labels is of length zero after coercion,
it has the same effect as supplying TRUE.