| mmstat.getDataNames | R Documentation |
Returns the names of data sets and stores them in the internal environment. The name of the data set is base name without extension.
mmstat.getDataNames(...)
... |
character: names of the data sets. |
the names of the data sets
files <- mmstat.rds("HAIR.EYE.COLOR", "TITANIC")
mmstat.getDataNames(files)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.