| mmstat.ui.elem | R Documentation |
Adds a new UI element to the app interface. The following types from Shiny are allowed:
actionButton,
checkboxInput,
checkboxGroupInput,
dateInput,
dateRangeInput,
fileInput,
helpText,
numericInput,
radioButtons,
selectInput,
sliderInput,
submitButton, and
textInput.
Additionally some standard statistical UI elements are supported (links go to the Shiny element used):
sampleSize,
drawSample,
speedSlider,
confidenceLevel,
significance,
testHypotheses,
dataSet,
variable1,
variableN, and
fontSize.
Partially these elements have default settings which can be overwritten.
mmstat.ui.elem(inputId, type, ...)
inputId |
character: input slot that will be used to access the value |
type |
character: element type |
... |
further named parameter to Shiny UI elements |
nothing
mmstat.ui.elem(inputId="alpha", type="significance")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.