| toHTML.html_matrix | R Documentation |
Returns a HTMl representation of a matrix and optionally shows the result in the browser.
If you decide to view the result in a browser then the HTML will be written to a temporary file and
utils::browseURL() called
## S3 method for class 'html_matrix' toHTML(x, browser = FALSE, ...) ## S3 method for class 'table' toHTML(x, browser = FALSE, ...) ## S3 method for class 'matrix' toHTML(x, browser = FALSE, ...)
x |
html_matrix object |
browser |
logical: show HTML in a browser (default: |
... |
further parameters to |
html_matrix object
library("tools")
m <- matrix(1:12, ncol=4)
hm <- html_matrix(m)
html <- toHTML(hm, browser=interactive())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.