Learn R Programming

HKRbook (version 0.1.3)

toRDS: toRDS

Description

Saves one or more data sets in RDS format to a temporary directory (tmpdir()). Data sets must have the class ts or something that can be converted to a data frame, e.g. matrix, table, etc.

Usage

toRDS(...)

Value

returns the name of the created files

Arguments

...

data sets to save

Examples

Run this code
toRDS(Titanic) # saves to tempdir/Titanic.rds

Run the code above in your browser using DataLab