powered by
Shiny app for the association coefficients between two categorical variables. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.
men_asso(...)
nothing
one or more data sets
if (interactive()) men_asso() if (interactive()) men_asso(HairEyeColor, Titanic)
Run the code above in your browser using DataLab