powered by
Shiny app for visualizing a univariate numeric variable as histögram. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory. #'
men_hist(...)
nothing
one or more data sets
if (interactive()) men_hist() if (interactive()) men_hist(iris)
Run the code above in your browser using DataLab