powered by
Shiny app for frequency tables for two categorical variables. If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.
men_tab(...)
nothing
one or more data sets
if (interactive()) men_tab() if (interactive()) men_tab(HairEyeColor, Titanic)
Run the code above in your browser using DataLab