powered by
Shiny app for classical time series analysis If no data are given then the default data from the book will be used. Otherwise the data will be stored as RDS file in a temporary directory.
men_time(...)
nothing
one or more time series
if (interactive()) men_time() if (interactive()) men_time(co2)
Run the code above in your browser using DataLab