Shiny app for visualizing the univariate numeric variable, e.g. boxplot, stripchart, histogram,
and cumulative distribution function.
If no data are given then the default data from the book will be used.
Otherwise the data will be stored as RDS file in a temporary directory.