Learn R Programming

HKRbook (version 0.1.3)

mmstat.ui.elem: mmstat.ui.elem

Description

Adds a new UI element to the app interface. The following types from Shiny are allowed:

Additionally some standard statistical UI elements are supported (links go to the Shiny element used):

Partially these elements have default settings which can be overwritten.

Usage

mmstat.ui.elem(inputId, type, ...)

Value

nothing

Arguments

inputId

character: input slot that will be used to access the value

type

character: element type

...

further named parameter to Shiny UI elements

Examples

Run this code
mmstat.ui.elem(inputId="alpha", type="significance")

Run the code above in your browser using DataLab