powered by
Adds a new UI element to the app interface. The following types from Shiny are allowed:
actionButton,
actionButton
checkboxInput,
checkboxInput
checkboxGroupInput,
checkboxGroupInput
dateInput,
dateInput
dateRangeInput,
dateRangeInput
fileInput,
fileInput
helpText,
helpText
numericInput,
numericInput
radioButtons,
radioButtons
selectInput,
selectInput
sliderInput,
sliderInput
submitButton, and
submitButton
textInput.
textInput
Additionally some standard statistical UI elements are supported (links go to the Shiny element used):
sampleSize,
sampleSize
drawSample,
drawSample
speedSlider,
speedSlider
confidenceLevel,
confidenceLevel
significance,
significance
testHypotheses,
testHypotheses
dataSet,
dataSet
variable1,
variable1
variableN, and
variableN
fontSize.
fontSize
Partially these elements have default settings which can be overwritten.
mmstat.ui.elem(inputId, type, ...)
nothing
character: input slot that will be used to access the value
character: element type
further named parameter to Shiny UI elements
mmstat.ui.elem(inputId="alpha", type="significance")
Run the code above in your browser using DataLab