powered by
Saves one or more data sets in RDS format to a temporary directory (tmpdir()). Data sets must have the class ts or something that can be converted to a data frame, e.g. matrix, table, etc.
tmpdir()
ts
matrix
table
toRDS(...)
returns the name of the created files
data sets to save
toRDS(Titanic) # saves to tempdir/Titanic.rds
Run the code above in your browser using DataLab